@@ -207,4 +207,10 @@ class Client(BaseWhatsAppClient):
         return await self.chat_manager.send_message(chat_query, message, force_open)
 
     async def send_file(self, chat_name, path):
-        return await self.chat_manager.send_file(chat_name, path)
\ No newline at end of file
+        return await self.chat_manager.send_file(chat_name, path)
+
+    async def new_group(self, group_name: str, members: list[str]):
+        return await self.chat_manager.new_group(group_name, members)
+
+    async def add_members_to_group(self, group_name: str, members: list[str]):
+        return await self.chat_manager.add_members_to_group(group_name, members)
\ No newline at end of file
